list_deps: List dependencies of reports within a factory

Description Usage Arguments

View source: R/list_deps.R

Description

This function can be used to list package dependencies based of the reports within the factory. It is a wrapper for checkpoint::scanForPackages.

Usage

1
list_deps(factory = ".", missing = FALSE)

Arguments

factory

The path to the report factory or a folder within the desired factory. Defaults to the current directory.

missing

A logical indicating if only missing dependencies should be listed (TRUE); otherwise, all packages needed in the reports are listed; defaults to FALSE


tjtnew/reportfactory documentation built on Dec. 31, 2020, 8:40 a.m.